cytoflow.views package
======================

Submodules
----------

cytoflow.views.histogram module
-------------------------------

.. automodule:: cytoflow.views.histogram
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.i_selectionview module
-------------------------------------

.. automodule:: cytoflow.views.i_selectionview
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.i_view module
----------------------------

.. automodule:: cytoflow.views.i_view
    :members:
    :undoc-members:
    :show-inheritance:

cytoflow.views.range_selection module
-------------------------------------

.. automodule:: cytoflow.views.range_selection
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: cytoflow.views
    :members:
    :undoc-members:
    :show-inheritance:
